=encoding utf8

=head1 NAME

En::Latn - Package for language En

=cut

package Locale::CLDR::Locales::En::Latn;

# This file auto generated
#	on Fri 17 Jan 12:03:31 pm GMT

use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use feature 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::En');

no Moo;

1;
